Struct yew_agent::AgentLink[][src]

pub struct AgentLink<AGN: Agent> { /* fields omitted */ }
Link to agent’s scope for creating callbacks.

Implementations

Send response to an agent.

Send a message to the agent

Send an input to self

Create a callback which will send a message to the agent when invoked.

This method creates a Callback which returns a Future which returns a message to be sent back to the agent

Panics

If the future panics, then the promise will not resolve, and will leak.

This method creates a Callback from FnOnce which returns a Future which returns a message to be sent back to the agent.

Panics

If the future panics, then the promise will not resolve, and will leak.

This method processes a Future that returns a message and sends it back to the agent.

Panics

If the future panics, then the promise will not resolve, and will leak.