Struct yew_agent::utils::store::StoreWrapper [−][src]
pub struct StoreWrapper<S: Store> {
pub handlers: HashSet<HandlerId>,
pub link: AgentLink<Self>,
pub state: Rc<RefCell<S>>,
pub self_dispatcher: Dispatcher<Self>,
}Expand description
Hides the full context Agent from a Store and does the boring data wrangling logic
Fields
handlers: HashSet<HandlerId>Currently subscribed components and agents
link: AgentLink<Self>Link to itself so Store::handle_input can send actions to reducer
state: Rc<RefCell<S>>The actual Store
self_dispatcher: Dispatcher<Self>A circular dispatcher to itself so the store is not removed