Trait yew_agent::utils::store::Bridgeable[][src]

pub trait Bridgeable: Sized + 'static {
    type Wrapper: Agent;
    fn bridge(
        callback: Callback<<Self::Wrapper as Agent>::Output>
    ) -> Box<dyn Bridge<Self::Wrapper>>; }
Allows us to communicate with a store

Associated Types

A wrapper for the store we want to bridge to, which serves as a communication intermediary

Required methods

Creates a messaging bridge between a worker and the component.

Implementors

Implementation of bridge creation