Crate yew_agent[−][src]
This module contains types to support multi-threading and state management.
Modules
Structs
Link to agent’s scope for creating callbacks.
Create a single instance in the current thread.
A newtype around a bridge to indicate that it is distinct from a normal bridge
Id of responses handler.
Create an instance in the current thread.
Create a new instance for every bridge.
Create a single instance in a tab.
State handle for use_bridge hook
Traits
Declares the behavior of the agent.
Bridge to a specific kind of worker.
This trait allows registering or getting the address of a worker.
This trait allows the creation of a dispatcher to an existing agent that will not send replies when messages are sent.
Implements rules to register a worker in a separate thread.
Functions
A hook to bridge to an Agent.