pub struct AgentLink<AGN: Agent> { /* fields omitted */ }
Link to agent’s scope for creating callbacks.
Send response to an agent.
Send a message to the agent
Create a callback which will send a message to the agent when invoked.
This method creates a Callback which returns a Future which
returns a message to be sent back to the agent
If the future panics, then the promise will not resolve, and
will leak.
This method creates a Callback from FnOnce which returns a Future
which returns a message to be sent back to the agent.
If the future panics, then the promise will not resolve, and
will leak.
This method processes a Future that returns a message and sends it back to the agent.
If the future panics, then the promise will not resolve, and will leak.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Convert self to a value of a Properties struct.
Convert self to a value of a Properties struct.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<T> Any for T where
T: Any,