Module yew_agent::utils::store [−][src]
Structs
A wrapper ensuring state observers can only borrow the state immutably
Hides the full context Agent from a Store and does the boring data wrangling logic
Traits
Allows us to communicate with a store
A functional state wrapper, enforcing a unidirectional data flow and consistent state to the observers.